@@ -94,6 +94,8 @@ gcm_window_set_parent_xid (GtkWindow *window, guint32 xid)
 		g_warning ("failed to get parent window");
 		return;
 	}
+
+	gtk_widget_realize (GTK_WIDGET (window));
 	our_window = gtk_widget_get_window (GTK_WIDGET (window));
 	if (our_window == NULL) {
 		g_warning ("failed to get our window");
@@ -770,7 +772,7 @@ gcm_calib_setup_page_summary (GcmCalibratePriv *calib)
 	case CD_DEVICE_KIND_PRINTER:
 		/* TRANSLATORS: this is the final summary */
 		gcm_calib_add_page_para (content, _("The printer has been calibrated successfully."));
-		gcm_calib_add_page_para (content, _("Docments printed from this device will be color managed."));
+		gcm_calib_add_page_para (content, _("Documents printed from this device will be color managed."));
 		break;
 	default:
 		/* TRANSLATORS: this is the final summary */
